# Windows 96 msgroom bot library
Create a Windows 96 msgroom bot using this library!
# What is Windows 96 msgroom?
A website where you can talk with other people: [Click here](https://msgroom.windows96.net/).
# Installation
To install from the git repository, use this command:
```
<your python interpreter> -m pip install git+github.com/geoegii555/w96msgroom.py@master
```
To install from PyPi, use this command:
```
<your python interpreter> -m pip install w96msgroom
```